@@ -14,9 +14,6 @@ class AndParser[E, O, O2](IParser[E, tuple[O, O2]]):
         self._p1 = p1
         self._p2 = p2
 
-    def expect(self) -> list[str]:
-        return self._p1.expect() + self._p2.expect()
-
     def parse(self, stream: Sequence[E]) -> tuple[tuple[O, O2], Sequence[E]]:
         (v1, stream1) = self._p1.parse(stream)
         (v2, stream2) = self._p2.parse(stream1)
