@@ -8,9 +8,6 @@ class AttemptParser[E, O](IParser[E, O | None]):
     def __init__(self, p: IParser[E, O]) -> None:
         self._p = p
 
-    def expect(self) -> list[str]:
-        return self._p.expect()
-
     def parse(self, stream: Sequence[E]) -> tuple[O | None, Sequence[E]]:
         try:
             return self._p.parse(stream)
