@@ -9,13 +9,6 @@ class ChoiceParser[E, O](IParser[E, O]):
     def __init__(self, *elements: IParser[E, O]) -> None:
         self._elements = elements
 
-    def expect(self) -> list[str]:
-        result = [];
-        for e in self._elements:
-            result += e.expect()
-
-        return result
-
     def parse(self, stream: Sequence[E]) -> tuple[O, Sequence[E]]:
         errors: list[ParserException] = []
         for e in self._elements:
