@@ -6,16 +6,11 @@ class EofParser[E](IParser[None, Sequence[E]]):
     def __init__(self) -> None:
         pass
 
-    def expect(self) -> list[str]:
-        return ["EOF"]
-
     def parse(self, stream: Sequence[E]) -> tuple[None, Sequence[E]]:
         if len(stream) == 0:
             return (None, stream)
         else:
-            raise ParserException(expect=self.expect(), actual="{}".format(stream[0]))
-
-
+            raise ParserException(expect="EOF", actual="{}".format(stream[0]))
 
 def eof():
     return EofParser()
