@@ -4,9 +4,6 @@ from .parser import IParser
 class LazyParser[E, O](IParser[E, O]):
     _fn: Callable[[], IParser[E, O]]
 
-    def expect(self) -> list[str]:
-        return []
-
     def __init__(self, fn: Callable[[], IParser[E, O]]) -> None:
         self._fn = fn
 
