@@ -7,8 +7,8 @@ from .parser_exception import ParserException
 class TestMany1Parser:
     def test_ok(self):
         p = Many1Parser(DigitParser())
-        (value, stream) = p.parse("123hi")
-        assert value == ["1","2","3"]
+        (value, stream) = p.parse("12hi")
+        assert value == ["1","2"]
         assert stream == "hi"
 
     def test_nothing(self):
