@@ -10,9 +10,6 @@ class MapParser[E, O, O2](IParser[E, O2]):
         self._p = p
         self._fn = fn
 
-    def expect(self) -> list[str]:
-        return self._p.expect()
-
     def parse(self, stream: Sequence[E]) -> tuple[O2, Sequence[E]]:
         (v1, s) = self._p.parse(stream)
         return (self._fn(v1), s)
