@@ -9,9 +9,6 @@ class UntilParser[E](IParser[E, Sequence[E]]):
     def __init__(self, p: IParser[E, Any]) -> None:
         self.p = p
 
-    def expect(self) -> list[str]:
-        return self.p.expect()
-
     def parse(self, stream: Sequence[E]) -> tuple[Sequence[E], Sequence[E]]:
         for i in range(0, len(stream)):
             try:
@@ -20,7 +17,9 @@ class UntilParser[E](IParser[E, Sequence[E]]):
             except ParserException:
                 pass
 
-        raise ParserException(expect=self.expect(), actual="EOF")
+        n = len(stream)
+        _ = self.p.parse(stream[n:])
+        return (stream[:n], stream[n:])
 
 
 def until[E](p: IParser[E, Any])->IParser[E, Sequence[E]]:
